"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var test = require("tape");
var ip = require("ip");
var socket_1 = require("muweb-socket/socket");
var index_1 = require("../index");
var client_1 = require("mudb/client");
var schema_1 = require("./schema");
var url = "ws://" + ip.address() + ":" + process.env.PORT;
var PING_OPCODE = 0x9;
var PONG_OPCODE = 0xA;
function randomId() {
    return Math.random().toString(36).substr(2);
}
test('WebSocket - simulating network latency on client side', function (t) {
    t.plan(2);
    var timestamp;
    var upstreamLatency = 75;
    var downstreamLatency = 25;
    var socket = new socket_1.MuWebSocket({
        sessionId: randomId(),
        url: url,
    });
    var debugSocket = new index_1.MuDebugSocket({
        socket: socket,
        outLatency: upstreamLatency,
        inLatency: downstreamLatency,
    });
    var muClient = new client_1.MuClient(debugSocket);
    var clientProtocol = muClient.protocol(schema_1.protocolSchema);
    clientProtocol.configure({
        message: {
            pong: function (data) {
                var delay = Date.now() - timestamp;
                var latency = upstreamLatency + downstreamLatency;
                t.equal(data, PONG_OPCODE);
                t.ok(delay > latency, "client should receive opcode after >" + latency + " ms");
            },
        },
    });
    muClient.start({
        ready: function () {
            clientProtocol.server.message.ping(PING_OPCODE);
            timestamp = Date.now();
        },
    });
});
test('WebSocket - maintaining order of messages from client side', function (t) {
    var head = 10;
    var end = 64;
    t.plan(end - head);
    var socket = new socket_1.MuWebSocket({
        sessionId: randomId(),
        url: url,
    });
    var debugSocket = new index_1.MuDebugSocket({
        socket: socket,
        outLatency: 75,
        outJitter: 10,
        inLatency: 25,
        inJitter: 10,
    });
    var muClient = new client_1.MuClient(debugSocket);
    var clientProtocol = muClient.protocol(schema_1.protocolSchema);
    clientProtocol.configure({
        message: {
            pong: function (data) {
                t.equal(data, head++);
            },
        },
    });
    muClient.start({
        ready: function () {
            for (var i = head; i < end; ++i) {
                clientProtocol.server.message.ping(i);
            }
        },
    });
});
//# sourceMappingURL=web.js.map